"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FuzzySet_1 = require("../FuzzySet");
var LinguisticVariable_1 = require("../LinguisticVariable");
var membershipFunction_1 = require("../membershipFunction");
var FuzzyInferenceSystem_1 = require("./FuzzyInferenceSystem");
var poorService = new FuzzySet_1.FuzzySet('Poor').generateMembershipValues({
    type: membershipFunction_1.MembershipFunctionType.Gaussian,
    parameters: {
        center: 0,
        standardDeviation: 1.5,
        minValue: 0,
        maxValue: 10,
        step: 0.5,
    },
});
var goodService = new FuzzySet_1.FuzzySet('Good').generateMembershipValues({
    type: membershipFunction_1.MembershipFunctionType.Gaussian,
    parameters: {
        center: 5,
        standardDeviation: 1.5,
        minValue: 0,
        maxValue: 10,
        step: 0.5,
    },
});
var serviceVariable = new LinguisticVariable_1.LinguisticVariable('Service').addSet(poorService).addSet(goodService);
describe('FuzzyInferenceSystem', function () {
    it('should able to be created with no sets', function () {
        var tipper = new FuzzyInferenceSystem_1.FuzzyInferenceSystem('Tipper');
        expect(tipper.inputs).toHaveLength(0);
        expect(tipper.outputs).toHaveLength(0);
        expect(tipper.name).toBe('Tipper');
    });
    it('should be able to be created with some fuzzy sets', function () {
        var tipper = new FuzzyInferenceSystem_1.FuzzyInferenceSystem('Tipper', [serviceVariable], [serviceVariable]);
        expect(tipper.inputs).toHaveLength(1);
        expect(tipper.outputs).toHaveLength(1);
    });
    it('should be able to be add sets', function () {
        var tipper = new FuzzyInferenceSystem_1.FuzzyInferenceSystem('Tipper');
        expect(tipper.inputs).toHaveLength(0);
        expect(tipper.outputs).toHaveLength(0);
        tipper.addInput(serviceVariable);
        tipper.addOutput(serviceVariable);
        expect(tipper.inputs).toHaveLength(1);
        expect(tipper.outputs).toHaveLength(1);
    });
    it('should be able to chain add variables', function () {
        var tipper = new FuzzyInferenceSystem_1.FuzzyInferenceSystem('Tipper').addInput(serviceVariable).addOutput(serviceVariable);
        expect(tipper.inputs).toHaveLength(1);
        expect(tipper.outputs).toHaveLength(1);
    });
});
